find_int_gap() determines the start and end positions for gap intervals
in a sequence of integers. By default, the interval range to look for gaps is
defined by the minimum and maximum values of x; specify xmin and xmax
to change the range explicitly.
find_int_gap(x, xmin = min(x), xmax = max(x))A tibble of gap intervals of two columns:
start: left endpoint
end: right endpoint
If no gap intervals are found then an empty tibble
is returned.
An integer vector.
Left endpoint integer value.
Right endpoint integer value.