coalesce_capture_matrices() combines several capture matrices into one.
Each argument of ... should be a capture matrix in the sense of the output
by complete_capture_matrix(), meaning a character matrix of six columns
whose names are: year, mon, mday, hour, min or sec.
coalesce_capture_matrices(...)A single capture matrix whose values have been coalesced in the sense of coalesce().
A sequence of capture matrices.